@@ -25,6 +25,9 @@ LITECODER_DB_URL = "https://github.com/Sheshank-s/litecoder/releases/download/v1
 if not os.path.isfile(CITY_ALT_NAMES_PATH):
     download(CITY_ALT_NAMES_URL, CITY_ALT_NAMES_PATH, progressbar=True, verbose=False)
 
+if not os.path.isfile(LITECODER_DB_PATH):
+    download(LITECODER_DB_URL, LITECODER_DB_PATH, progressbar=True, verbose=False)
+
 logging.basicConfig(
     format='%(asctime)s | %(levelname)s : %(message)s',
     stream=sys.stdout,
@@ -32,14 +35,3 @@ logging.basicConfig(
 )
 
 logger = logging.getLogger('litecoder')
-
-
-def download_litecoder_db():
-    """Download sqlite database -- not needed for production, but useful
-    for exploration.
-
-    """
-
-    if not os.path.isfile(LITECODER_DB_PATH):
-        download(LITECODER_DB_URL, LITECODER_DB_PATH,
-                 progressbar=True, verbose=False)
